tidy conditional inference tree. Creates easily interpretable decision tree models that be shown with the visualize_model function.
Statistical significance required for a split , and minimum necessary samples in a terminal leaf can be controlled to create the desired tree visual.