plot and summarize shapley values from an xgboost model
tidy_shap(model, newdata, form = NULL, ..., top_n = 12, aggregate = NULL)list
returns a list with the following entries
: table of shaply values
: long table of feature and shaply values
: table summarizing shapley values. Includes correlation between shaps and feature values.
: one plot showing the relation between shaps and features
: returns the top 9 most important features as determined by sum of absolute shapley values, as a facetted scatterplot of feature vs shap