Finds the correlation between numeric variables in a data frame, chosen using tidyselect.
Additional parameters for the correlation test can be specified as in cor.test
iris %>%
auto_cor()
# don't use sparse if you're interested in only one target variableiris %>%
auto_cor(sparse = FALSE) %>%
dplyr::filter(x == "Petal.Length")