s3 method to automatically visualize the output of of a model object. Additional arguments can be supplied for the original function. Check the corresponding plot function documentation for any custom arguments.
visualize_model(model, ...)
# S3 method for class 'RandomForest'
visualize_model(model, ..., method)
# S3 method for class 'BinaryTree'
visualize_model(model, ..., method)
# S3 method for class 'glm'
visualize_model(model, ..., method)
# S3 method for class 'multinom'
visualize_model(model, ..., method)
# S3 method for class 'xgb.Booster'
visualize_model(model, top_n = 10L, as_table = FALSE, ..., method)
# Default S3 method
visualize_model(model, ..., method)a plot