s3 method to automatically visualize the output of of a model object. Additional arguments can be supplied for the original function. Check the corresponding plot function documentation for any custom arguments.
visualize_model(model, ...)# S3 method for RandomForest
visualize_model(model, ..., method)
# S3 method for BinaryTree
visualize_model(model, ..., method)
# S3 method for glm
visualize_model(model, ..., method)
# S3 method for multinom
visualize_model(model, ..., method)
# S3 method for xgb.Booster
visualize_model(model, top_n = 10L, as_table = FALSE, ..., method)
# S3 method for default
visualize_model(model, ..., method)
a plot
a model
additional arguments
choose amongst different visualization methods
return top n elements
= false, table or graph,